/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_oRxRGYUF);
  numBytes += sLine_init(&sLine_VrJ0vND8);
  numBytes += sTabhead_init(&sTabhead_L6aLlt30, &hTable_Ls1VVpyH);
  numBytes += sTabread_init(&sTabread_OTEA68DA, &hTable_Ls1VVpyH, false);
  numBytes += sTabread_init(&sTabread_nGoEaGuM, &hTable_Ls1VVpyH, false);
  numBytes += sLine_init(&sLine_jP9rn8K9);
  numBytes += sLine_init(&sLine_D7dE5ZKw);
  numBytes += sLine_init(&sLine_9xNS84Sd);
  numBytes += sTabhead_init(&sTabhead_1z9RBq4S, &hTable_WhfH8YcT);
  numBytes += sTabread_init(&sTabread_TrFWJxNL, &hTable_WhfH8YcT, false);
  numBytes += sTabread_init(&sTabread_8hQUqzNA, &hTable_WhfH8YcT, false);
  numBytes += sLine_init(&sLine_0exMH4Xc);
  numBytes += sTabwrite_init(&sTabwrite_eR6cTgfN, &hTable_Ls1VVpyH);
  numBytes += sTabwrite_init(&sTabwrite_BMYFOq4t, &hTable_WhfH8YcT);
  numBytes += sRPole_init(&sRPole_jCiGmcIE);
  numBytes += sRPole_init(&sRPole_EArzdfS3);
  numBytes += sRPole_init(&sRPole_U7YSa7ZB);
  numBytes += sDel1_init(&sDel1_hoYmQqoj);
  numBytes += sLine_init(&sLine_JmQI3gnm);
  numBytes += sLine_init(&sLine_vC3SG7HZ);
  numBytes += sRPole_init(&sRPole_1dunZAVl);
  numBytes += sRPole_init(&sRPole_lCyxwSqW);
  numBytes += sRPole_init(&sRPole_GBgfK7Lw);
  numBytes += sDel1_init(&sDel1_G8NiDopC);
  numBytes += sLine_init(&sLine_gagOS7W9);
  numBytes += sLine_init(&sLine_PRi5SYi2);
  numBytes += sLine_init(&sLine_jTSezsyS);
  numBytes += sLine_init(&sLine_akjWxHKk);
  numBytes += cVar_init_f(&cVar_lOWHpRbI, 0.0f);
  numBytes += cVar_init_f(&cVar_DNXyPhr2, 0.0f);
  numBytes += cVar_init_f(&cVar_Y8jjW8rX, 0.0f);
  numBytes += cVar_init_f(&cVar_fpm8B1Rn, 0.0f);
  numBytes += cSlice_init(&cSlice_5tj1xf4R, 1, -1);
  numBytes += cVar_init_f(&cVar_LHUDV3Ii, 0.5f);
  numBytes += cSlice_init(&cSlice_OVgL4EaV, 1, -1);
  numBytes += cVar_init_f(&cVar_vK08lEUW, 0.2f);
  numBytes += cSlice_init(&cSlice_7gCkPhxF, 1, -1);
  numBytes += cVar_init_f(&cVar_6mERq7CP, 500.0f);
  numBytes += cSlice_init(&cSlice_JvGyOUfz, 1, -1);
  numBytes += cVar_init_f(&cVar_rwfj8GOR, 0.25f);
  numBytes += cDelay_init(this, &cDelay_niFvq51I, 0.0f);
  numBytes += cDelay_init(this, &cDelay_45yxREuy, 0.0f);
  numBytes += hTable_init(&hTable_Ls1VVpyH, 256);
  numBytes += cDelay_init(this, &cDelay_ZrJQWxxf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2CqFZJDa, 0.0f);
  numBytes += hTable_init(&hTable_WhfH8YcT, 256);
  numBytes += cVar_init_f(&cVar_9QK88sUr, 8000.0f);
  numBytes += cBinop_init(&cBinop_2HB7nBzu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VfRD2TCJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IQ2x3sua, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ohn7zukt, 8000.0f);
  numBytes += cBinop_init(&cBinop_dc9yg5Eb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wMi9ilX0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nq1URlXD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7C694S1O, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Htj13Qzx, 300.0f);
  numBytes += cBinop_init(&cBinop_dephv4fo, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_DV9F9Vvh, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_8KGzaxbF, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_kCFHpSPW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4UY0BBZl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rSW9oRII, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_WSLXkSPm, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_ehGlWwp4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o92NmmLf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LZrIXqO6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TkbOQ6Qy, 8000.0f);
  numBytes += cBinop_init(&cBinop_6e4Hkkam, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VBYkEYjh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TcpDwtq5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vcEws2m0, 8000.0f);
  numBytes += cBinop_init(&cBinop_2Z5BYC61, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_42QbeMz5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZSx23Ers, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LInhsxCX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GxhKlf0T, 300.0f);
  numBytes += cBinop_init(&cBinop_o4KYskGo, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_JaRKL2Mr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eloim9KZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BSz0l71g, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4cLN6mx0, 1.0f);
  numBytes += cIf_init(&cIf_fxqbWVPN, false);
  numBytes += cIf_init(&cIf_R6SNyyrF, false);
  numBytes += cVar_init_f(&cVar_owyakTwO, 0.0f);
  numBytes += cVar_init_f(&cVar_6luy8jm6, 0.0f);
  numBytes += cVar_init_f(&cVar_ouOkQ7uM, 60000.0f);
  numBytes += cVar_init_f(&cVar_2vLppncU, 500.0f);
  numBytes += cSlice_init(&cSlice_vCNxd3NW, 1, -1);
  numBytes += cSlice_init(&cSlice_CMZbqEtk, 1, -1);
  numBytes += cVar_init_f(&cVar_vL45sRqB, 0.0f);
  numBytes += cIf_init(&cIf_ROUswLlS, false);
  numBytes += cBinop_init(&cBinop_0vLmhoCh, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_h6jlEaRP, 120.0f);
  numBytes += cBinop_init(&cBinop_65EglLnc, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_o5ebeqU1, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_Ls1VVpyH);
  hTable_free(&hTable_WhfH8YcT);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_Ls1VVpyH; // del-1011-delayL
    case 0xF057CB49: return &hTable_WhfH8YcT; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ayh5YgdQ_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DXjZ7lD7_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1o68kBG6_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SCfmB3kO_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VDtG8WSp_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I7JpN8rn_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LKcZhsSi_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vshiqa8f_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Au8kwmW6_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vNdPnkuv_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UJcO2fOn_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Iq6EEJkG_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_lOWHpRbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PSoo1oxF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_DNXyPhr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IVJFOdZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_Y8jjW8rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MoY2sCKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_fpm8B1Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYc0sM4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_GGoHSuiT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5tj1xf4R, 0, m, &cSlice_5tj1xf4R_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_5tj1xf4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LkqPboid_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LkqPboid_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_LHUDV3Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LkqPboid_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_LkqPboid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Au8kwmW6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_DJpcW0T7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OVgL4EaV, 0, m, &cSlice_OVgL4EaV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_smybNLeG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_OVgL4EaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zj0knMyR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zj0knMyR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_vK08lEUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zj0knMyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_zj0knMyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LKcZhsSi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_mfV66HPh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7gCkPhxF, 0, m, &cSlice_7gCkPhxF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GGoHSuiT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_7gCkPhxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mMw4lDez_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mMw4lDez_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_6mERq7CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mMw4lDez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_mMw4lDez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vNdPnkuv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_2fe4Ju5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KE0CP1wy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KE0CP1wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ypoLdb0J_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_9GXcr5mS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kcrf5gMB_sendMessage(_c, 0, m);
  cMsg_k2bNZgqj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_1l6VSbfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jG0VNnTU_sendMessage(_c, 0, m);
  cMsg_TfEIrizF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ypoLdb0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vDQbyY7N_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vDQbyY7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0S0KrMbU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r3rB5U8w_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_r3rB5U8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MktcqzSr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_0S0KrMbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Iakhr6Xh_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Iakhr6Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kBEQJTLj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MktcqzSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_P69sxV8R_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_P69sxV8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_H8XaehKY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kBEQJTLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_9GXcr5mS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_H8XaehKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_1l6VSbfe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_u8jJKt05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gpt2oeWo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gpt2oeWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_kbc4mmHQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kbc4mmHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tyTtkgBY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_tyTtkgBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dM0zohZa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y933Rug1_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Y933Rug1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7irOPUB6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_dM0zohZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XPddFg6S_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XPddFg6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_C9xTavWn_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7irOPUB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YS35M8vj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YS35M8vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_If2rQCsQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_If2rQCsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K5YqCZGL_sendMessage(_c, 0, m);
  cMsg_9TWYqtDM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_C9xTavWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JTS51kGp_sendMessage(_c, 0, m);
  cMsg_fimPHY3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_smybNLeG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JvGyOUfz, 0, m, &cSlice_JvGyOUfz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mfV66HPh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_JvGyOUfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2W6uiajN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2W6uiajN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_rwfj8GOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2W6uiajN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_2W6uiajN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vshiqa8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_qkqrefQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Sti9AElH_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Sti9AElH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gBhf0rsm_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_niFvq51I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_niFvq51I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_45yxREuy, 0, m, &cDelay_45yxREuy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_niFvq51I, 0, m, &cDelay_niFvq51I_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eR6cTgfN, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_45yxREuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_45yxREuy, m);
  cMsg_iX8nHCzC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_jNTxtPMt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mgEvBh5a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_gCHmY0LW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qBhfTp0d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_Ls1VVpyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJLWHEtt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_niFvq51I, 2, m, &cDelay_niFvq51I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_omRuQoOz_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qBhfTp0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Ls1VVpyH, 0, m, &hTable_Ls1VVpyH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gBhf0rsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_gCHmY0LW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_iX8nHCzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Ls1VVpyH, 0, m, &hTable_Ls1VVpyH_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_omRuQoOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_niFvq51I, 0, m, &cDelay_niFvq51I_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PJLWHEtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_45yxREuy, 2, m, &cDelay_45yxREuy_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mgEvBh5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eR6cTgfN, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_GxTQkH0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uafWS6lb_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_uafWS6lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Mg4DPr1h_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_ZrJQWxxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZrJQWxxf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2CqFZJDa, 0, m, &cDelay_2CqFZJDa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrJQWxxf, 0, m, &cDelay_ZrJQWxxf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BMYFOq4t, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_2CqFZJDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2CqFZJDa, m);
  cMsg_ZTye0AgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_xTm0aPLY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bGEL3T2g_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_2BxJ9Me6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L1aRBGvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_WhfH8YcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l8cvLuct_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrJQWxxf, 2, m, &cDelay_ZrJQWxxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KoIuqx3u_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_L1aRBGvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WhfH8YcT, 0, m, &hTable_WhfH8YcT_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Mg4DPr1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2BxJ9Me6_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZTye0AgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WhfH8YcT, 0, m, &hTable_WhfH8YcT_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_KoIuqx3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrJQWxxf, 0, m, &cDelay_ZrJQWxxf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_l8cvLuct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_2CqFZJDa, 2, m, &cDelay_2CqFZJDa_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bGEL3T2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BMYFOq4t, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_9QK88sUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HB7nBzu, HV_BINOP_MULTIPLY, 0, m, &cBinop_2HB7nBzu_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9JKr97oB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4xM6aXbw_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_4xM6aXbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oPmbpaUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_2HB7nBzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xdY5NTUC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TUtq9Ktq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HB7nBzu, HV_BINOP_MULTIPLY, 1, m, &cBinop_2HB7nBzu_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oPmbpaUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TUtq9Ktq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xdY5NTUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hmIiZ89b_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_hmIiZ89b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2P0hO8n0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IQ2x3sua, m);
}

void Heavy_WSTD_DLAY::cBinop_2P0hO8n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VfRD2TCJ, m);
}

void Heavy_WSTD_DLAY::cVar_ohn7zukt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dc9yg5Eb, HV_BINOP_MULTIPLY, 0, m, &cBinop_dc9yg5Eb_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hNbPHlgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_viUVymMX_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_viUVymMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tN3mOUdn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_dc9yg5Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sBF0UDll_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_X2SfxcFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dc9yg5Eb, HV_BINOP_MULTIPLY, 1, m, &cBinop_dc9yg5Eb_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_tN3mOUdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_X2SfxcFo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sBF0UDll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gXihUUK2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gXihUUK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2DdSZVpW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nq1URlXD, m);
}

void Heavy_WSTD_DLAY::cBinop_2DdSZVpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wMi9ilX0, m);
}

void Heavy_WSTD_DLAY::cBinop_ezXxDlIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pTOPFgGP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pTOPFgGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ATrSjBFs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pnEyKxrf_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Htj13Qzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_GAP5ejKt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FxvCtDrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y0PXtR22_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_y0PXtR22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dephv4fo, HV_BINOP_DIVIDE, 1, m, &cBinop_dephv4fo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ATrSjBFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_naVoCblQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_naVoCblQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DV9F9Vvh, m);
}

void Heavy_WSTD_DLAY::cMsg_0vwcUWlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yfuTCJUr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yfuTCJUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ezXxDlIs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pnEyKxrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7C694S1O, m);
}

void Heavy_WSTD_DLAY::cBinop_GAP5ejKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_gQ4AEJkq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gQ4AEJkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dephv4fo, HV_BINOP_DIVIDE, 0, m, &cBinop_dephv4fo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dephv4fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0vwcUWlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_mu5sQrzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sUsMWdHP_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_sUsMWdHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gL0IyDF9_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_8KGzaxbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OA8umgrl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_ga3i10j4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_us2ZoiDn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kCFHpSPW, m);
}

void Heavy_WSTD_DLAY::cBinop_gL0IyDF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4UY0BBZl, m);
}

void Heavy_WSTD_DLAY::cMsg_OA8umgrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ga3i10j4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_us2ZoiDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rSW9oRII, m);
}

void Heavy_WSTD_DLAY::cMsg_QOMQIZUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_laYwceiQ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_laYwceiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qxPsXLDk_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_WSLXkSPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qtE5D0IN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_3m30enIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XwDq5v8m_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ehGlWwp4, m);
}

void Heavy_WSTD_DLAY::cBinop_qxPsXLDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_o92NmmLf, m);
}

void Heavy_WSTD_DLAY::cMsg_qtE5D0IN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3m30enIS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XwDq5v8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LZrIXqO6, m);
}

void Heavy_WSTD_DLAY::cVar_TkbOQ6Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6e4Hkkam, HV_BINOP_MULTIPLY, 0, m, &cBinop_6e4Hkkam_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_aAUmy21v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zL2Ufpoe_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_zL2Ufpoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kyGpMvBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_6e4Hkkam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_v2blRgYQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4y7WCigx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6e4Hkkam, HV_BINOP_MULTIPLY, 1, m, &cBinop_6e4Hkkam_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kyGpMvBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4y7WCigx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_v2blRgYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4vhkweN6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4vhkweN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e28ilpJY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TcpDwtq5, m);
}

void Heavy_WSTD_DLAY::cBinop_e28ilpJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VBYkEYjh, m);
}

void Heavy_WSTD_DLAY::cVar_vcEws2m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Z5BYC61, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Z5BYC61_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_yoHvY6TW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fxL6CSHp_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_fxL6CSHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CUZVq783_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_2Z5BYC61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_U40pQ03y_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NCk2Cwl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Z5BYC61, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Z5BYC61_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_CUZVq783_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NCk2Cwl1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_U40pQ03y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SfM7CaC8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SfM7CaC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qYaqYkmT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZSx23Ers, m);
}

void Heavy_WSTD_DLAY::cBinop_qYaqYkmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_42QbeMz5, m);
}

void Heavy_WSTD_DLAY::cBinop_u2MgFwlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2XkIfNPo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2XkIfNPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xyX7Gl8O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_943yjbFG_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_GxhKlf0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_hCiIRBn7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TbLhQSw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_chyAJ0Qc_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_chyAJ0Qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4KYskGo, HV_BINOP_DIVIDE, 1, m, &cBinop_o4KYskGo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xyX7Gl8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WYPMhJCd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WYPMhJCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JaRKL2Mr, m);
}

void Heavy_WSTD_DLAY::cMsg_szpbY1fQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gP3rWSXq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gP3rWSXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u2MgFwlu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_943yjbFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LInhsxCX, m);
}

void Heavy_WSTD_DLAY::cBinop_hCiIRBn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_oJtRrWm8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oJtRrWm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4KYskGo, HV_BINOP_DIVIDE, 0, m, &cBinop_o4KYskGo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_o4KYskGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_szpbY1fQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_Kcrf5gMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jP9rn8K9, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_jG0VNnTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oRxRGYUF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_TfEIrizF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D7dE5ZKw, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_k2bNZgqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0exMH4Xc, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_fimPHY3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PRi5SYi2, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_K5YqCZGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vC3SG7HZ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_JTS51kGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_akjWxHKk, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_9TWYqtDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jTSezsyS, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_4owFhslD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VrJ0vND8, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_6ZMmhY4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9xNS84Sd, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_K8E0Schu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JmQI3gnm, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_dOtTpXC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gagOS7W9, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_4cLN6mx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7HdHnfXZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YYo1mTka_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6CB0Q7gD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7HdHnfXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4cLN6mx0, 1, m, &cVar_4cLN6mx0_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_fxqbWVPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_DNXyPhr2, 0, m, &cVar_DNXyPhr2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_R6SNyyrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_DNXyPhr2, 0, m, &cVar_DNXyPhr2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_owyakTwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6SNyyrF, 0, m, &cIf_R6SNyyrF_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_6luy8jm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fxqbWVPN, 0, m, &cIf_fxqbWVPN_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_ouOkQ7uM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_65EglLnc, HV_BINOP_DIVIDE, 0, m, &cBinop_65EglLnc_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_2vLppncU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5ebeqU1, HV_BINOP_MULTIPLY, 1, m, &cBinop_o5ebeqU1_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_pexQtiRp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vCNxd3NW, 0, m, &cSlice_vCNxd3NW_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CMZbqEtk, 0, m, &cSlice_CMZbqEtk_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HYfHnpfJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_13P0R6Q2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_vCNxd3NW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_vL45sRqB, 0, m, &cVar_vL45sRqB_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_vL45sRqB, 0, m, &cVar_vL45sRqB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_CMZbqEtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0vLmhoCh, HV_BINOP_NEQ, 1, m, &cBinop_0vLmhoCh_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vL45sRqB, 1, m, &cVar_vL45sRqB_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0vLmhoCh, HV_BINOP_NEQ, 1, m, &cBinop_0vLmhoCh_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vL45sRqB, 1, m, &cVar_vL45sRqB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_vL45sRqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_GO42f8qn_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_ROUswLlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7bWm0iJy_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WoMdREDf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_WoMdREDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vL45sRqB, 0, m, &cVar_vL45sRqB_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7bWm0iJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vLmhoCh, HV_BINOP_NEQ, 1, m, &cBinop_0vLmhoCh_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0vLmhoCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ROUswLlS, 1, m, &cIf_ROUswLlS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_13P0R6Q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ROUswLlS, 0, m, &cIf_ROUswLlS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_HYfHnpfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vLmhoCh, HV_BINOP_NEQ, 0, m, &cBinop_0vLmhoCh_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_h6jlEaRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wdZTHfSq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Do51plln_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_cW6j6YjP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NMhN2h3B_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4ORHemU_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0KSqijzq_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HnP389jL_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ss1CopIN_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IajXINaz_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YUoVczVr_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ix36iyCv_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zgyta8Ky_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_231VeMb4_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FOplblaN_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zr6teHZe_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CfQcp0OY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_NMhN2h3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Zrwy8H2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_l4ORHemU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PMKztvbE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_0KSqijzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0H2swZ5q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_HnP389jL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OfO4e4MW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Ss1CopIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5u8l264h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_IajXINaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZjKF9MhJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_YUoVczVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m14wKhsw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ix36iyCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oWKQ8Rpr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_zgyta8Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7PK2ojLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_231VeMb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v6zfs1nE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_FOplblaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uTop4YNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_zr6teHZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BXuyZJH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CfQcp0OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I1YNoZRW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_65EglLnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5ebeqU1, HV_BINOP_MULTIPLY, 0, m, &cBinop_o5ebeqU1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_o5ebeqU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pexQtiRp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_Do51plln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ouOkQ7uM, 0, m, &cVar_ouOkQ7uM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2vLppncU, 0, m, &cVar_2vLppncU_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_wdZTHfSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_65EglLnc, HV_BINOP_DIVIDE, 1, m, &cBinop_65EglLnc_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_MHtjeM6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2vLppncU, 0, m, &cVar_2vLppncU_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_fRbBa4dR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ouOkQ7uM, 0, m, &cVar_ouOkQ7uM_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2Zrwy8H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PMKztvbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_0H2swZ5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_OfO4e4MW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5u8l264h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZjKF9MhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_m14wKhsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oWKQ8Rpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7PK2ojLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_v6zfs1nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_uTop4YNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5BXuyZJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_I1YNoZRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHtjeM6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fRbBa4dR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gYc0sM4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJpcW0T7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_PSoo1oxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJpcW0T7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_eMTaHKFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fpm8B1Rn, 0, m, &cVar_fpm8B1Rn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NUnyh31E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lOWHpRbI, 0, m, &cVar_lOWHpRbI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1evg25er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y8jjW8rX, 0, m, &cVar_Y8jjW8rX_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IVJFOdZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJpcW0T7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_MoY2sCKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJpcW0T7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_GO42f8qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6luy8jm6, 0, m, &cVar_6luy8jm6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6CB0Q7gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BEPgOE4t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_REzot42V_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YYo1mTka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O2rCpaRb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AjRIhUI4_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_O2rCpaRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6SNyyrF, 1, m, &cIf_R6SNyyrF_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_AjRIhUI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_owyakTwO, 0, m, &cVar_owyakTwO_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_BEPgOE4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fxqbWVPN, 1, m, &cIf_fxqbWVPN_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_REzot42V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6luy8jm6, 0, m, &cVar_6luy8jm6_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_1o68kBG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eMTaHKFi_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_DXjZ7lD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NUnyh31E_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ayh5YgdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1evg25er_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_VDtG8WSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_owyakTwO, 0, m, &cVar_owyakTwO_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_vNdPnkuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4owFhslD_sendMessage(_c, 0, m);
  cMsg_6ZMmhY4n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_vshiqa8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K8E0Schu_sendMessage(_c, 0, m);
  cMsg_dOtTpXC5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_Au8kwmW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2fe4Ju5j_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_Iq6EEJkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LHUDV3Ii, 0, m, &cVar_LHUDV3Ii_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vK08lEUW, 0, m, &cVar_vK08lEUW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6mERq7CP, 0, m, &cVar_6mERq7CP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rwfj8GOR, 0, m, &cVar_rwfj8GOR_sendMessage);
  cMsg_qkqrefQw_sendMessage(_c, 0, m);
  cMsg_GxTQkH0G_sendMessage(_c, 0, m);
  cMsg_9JKr97oB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9QK88sUr, 0, m, &cVar_9QK88sUr_sendMessage);
  cMsg_hNbPHlgq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ohn7zukt, 0, m, &cVar_ohn7zukt_sendMessage);
  cMsg_FxvCtDrc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Htj13Qzx, 0, m, &cVar_Htj13Qzx_sendMessage);
  cMsg_aAUmy21v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TkbOQ6Qy, 0, m, &cVar_TkbOQ6Qy_sendMessage);
  cMsg_yoHvY6TW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vcEws2m0, 0, m, &cVar_vcEws2m0_sendMessage);
  cMsg_TbLhQSw6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GxhKlf0T, 0, m, &cVar_GxhKlf0T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8KGzaxbF, 0, m, &cVar_8KGzaxbF_sendMessage);
  cMsg_mu5sQrzJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WSLXkSPm, 0, m, &cVar_WSLXkSPm_sendMessage);
  cMsg_QOMQIZUf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_LKcZhsSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u8jJKt05_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_SCfmB3kO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4cLN6mx0, 0, m, &cVar_4cLN6mx0_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_UJcO2fOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h6jlEaRP, 0, m, &cVar_h6jlEaRP_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_I7JpN8rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cW6j6YjP_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_oRxRGYUF, VOf(Bf0));
    __hv_line_f(&sLine_VrJ0vND8, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_L6aLlt30, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_4UY0BBZl, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_rSW9oRII, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_kCFHpSPW, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_OTEA68DA, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_nGoEaGuM, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_jP9rn8K9, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_D7dE5ZKw, VOf(Bf0));
    __hv_line_f(&sLine_9xNS84Sd, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_1z9RBq4S, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_o92NmmLf, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_LZrIXqO6, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_ehGlWwp4, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_TrFWJxNL, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_8hQUqzNA, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_0exMH4Xc, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Eloim9KZ, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_eR6cTgfN, VIf(Bf0));
    __hv_varread_f(&sVarf_BSz0l71g, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_BMYFOq4t, VIf(Bf0));
    __hv_varread_f(&sVarf_IQ2x3sua, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_VfRD2TCJ, VOf(Bf1));
    __hv_rpole_f(&sRPole_jCiGmcIE, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Nq1URlXD, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_wMi9ilX0, VOf(Bf1));
    __hv_rpole_f(&sRPole_EArzdfS3, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7C694S1O, VOf(Bf0));
    __hv_rpole_f(&sRPole_U7YSa7ZB, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_hoYmQqoj, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_DV9F9Vvh, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_JmQI3gnm, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_vC3SG7HZ, VOf(Bf0));
    __hv_varread_f(&sVarf_TcpDwtq5, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_VBYkEYjh, VOf(Bf4));
    __hv_rpole_f(&sRPole_1dunZAVl, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ZSx23Ers, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_42QbeMz5, VOf(Bf4));
    __hv_rpole_f(&sRPole_lCyxwSqW, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_LInhsxCX, VOf(Bf6));
    __hv_rpole_f(&sRPole_GBgfK7Lw, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_G8NiDopC, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_JaRKL2Mr, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_gagOS7W9, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_PRi5SYi2, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_Eloim9KZ, VIf(Bf6));
    __hv_line_f(&sLine_jTSezsyS, VOf(Bf6));
    __hv_line_f(&sLine_akjWxHKk, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_BSz0l71g, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
