/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlDelay.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvSignalTabread.h"
#include "HvControlIf.h"
#include "HvSignalRPole.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_lOWHpRbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DNXyPhr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y8jjW8rX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fpm8B1Rn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GGoHSuiT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5tj1xf4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LHUDV3Ii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LkqPboid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DJpcW0T7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OVgL4EaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vK08lEUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zj0knMyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mfV66HPh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7gCkPhxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6mERq7CP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mMw4lDez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2fe4Ju5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KE0CP1wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9GXcr5mS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1l6VSbfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ypoLdb0J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vDQbyY7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r3rB5U8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0S0KrMbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iakhr6Xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MktcqzSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P69sxV8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kBEQJTLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H8XaehKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u8jJKt05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gpt2oeWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kbc4mmHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tyTtkgBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y933Rug1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dM0zohZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XPddFg6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7irOPUB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YS35M8vj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_If2rQCsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C9xTavWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_smybNLeG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_JvGyOUfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rwfj8GOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2W6uiajN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qkqrefQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Sti9AElH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_niFvq51I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_45yxREuy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jNTxtPMt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_gCHmY0LW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Ls1VVpyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qBhfTp0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gBhf0rsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iX8nHCzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_omRuQoOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PJLWHEtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mgEvBh5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GxTQkH0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uafWS6lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZrJQWxxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2CqFZJDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xTm0aPLY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_2BxJ9Me6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WhfH8YcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L1aRBGvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mg4DPr1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZTye0AgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KoIuqx3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l8cvLuct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bGEL3T2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9QK88sUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9JKr97oB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4xM6aXbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2HB7nBzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TUtq9Ktq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oPmbpaUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xdY5NTUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hmIiZ89b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2P0hO8n0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ohn7zukt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hNbPHlgq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_viUVymMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dc9yg5Eb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X2SfxcFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tN3mOUdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sBF0UDll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gXihUUK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DdSZVpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ezXxDlIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pTOPFgGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Htj13Qzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FxvCtDrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_y0PXtR22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ATrSjBFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_naVoCblQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0vwcUWlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yfuTCJUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pnEyKxrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GAP5ejKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQ4AEJkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dephv4fo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mu5sQrzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sUsMWdHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8KGzaxbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ga3i10j4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gL0IyDF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OA8umgrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_us2ZoiDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QOMQIZUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_laYwceiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WSLXkSPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3m30enIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxPsXLDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qtE5D0IN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XwDq5v8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TkbOQ6Qy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aAUmy21v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zL2Ufpoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6e4Hkkam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4y7WCigx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kyGpMvBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v2blRgYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4vhkweN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e28ilpJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vcEws2m0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yoHvY6TW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fxL6CSHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Z5BYC61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NCk2Cwl1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CUZVq783_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U40pQ03y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SfM7CaC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qYaqYkmT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u2MgFwlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2XkIfNPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GxhKlf0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TbLhQSw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_chyAJ0Qc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xyX7Gl8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WYPMhJCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_szpbY1fQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gP3rWSXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_943yjbFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hCiIRBn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oJtRrWm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o4KYskGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kcrf5gMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jG0VNnTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfEIrizF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k2bNZgqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fimPHY3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K5YqCZGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JTS51kGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9TWYqtDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4owFhslD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ZMmhY4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K8E0Schu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dOtTpXC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4cLN6mx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7HdHnfXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fxqbWVPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_R6SNyyrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_owyakTwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6luy8jm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ouOkQ7uM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2vLppncU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pexQtiRp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vCNxd3NW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_CMZbqEtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vL45sRqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ROUswLlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WoMdREDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7bWm0iJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0vLmhoCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_13P0R6Q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HYfHnpfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h6jlEaRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cW6j6YjP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_NMhN2h3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l4ORHemU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0KSqijzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HnP389jL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ss1CopIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IajXINaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YUoVczVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ix36iyCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zgyta8Ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_231VeMb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FOplblaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zr6teHZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CfQcp0OY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_65EglLnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o5ebeqU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Do51plln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wdZTHfSq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MHtjeM6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fRbBa4dR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Zrwy8H2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PMKztvbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0H2swZ5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OfO4e4MW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5u8l264h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZjKF9MhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m14wKhsw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWKQ8Rpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7PK2ojLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v6zfs1nE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uTop4YNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5BXuyZJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I1YNoZRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gYc0sM4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PSoo1oxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eMTaHKFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NUnyh31E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1evg25er_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IVJFOdZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MoY2sCKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GO42f8qn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CB0Q7gD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YYo1mTka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O2rCpaRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AjRIhUI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BEPgOE4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_REzot42V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1o68kBG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DXjZ7lD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ayh5YgdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VDtG8WSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vNdPnkuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vshiqa8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Au8kwmW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Iq6EEJkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LKcZhsSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SCfmB3kO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UJcO2fOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_I7JpN8rn_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_oRxRGYUF;
  SignalLine sLine_VrJ0vND8;
  SignalTabhead sTabhead_L6aLlt30;
  SignalTabread sTabread_OTEA68DA;
  SignalTabread sTabread_nGoEaGuM;
  SignalLine sLine_jP9rn8K9;
  SignalLine sLine_D7dE5ZKw;
  SignalLine sLine_9xNS84Sd;
  SignalTabhead sTabhead_1z9RBq4S;
  SignalTabread sTabread_TrFWJxNL;
  SignalTabread sTabread_8hQUqzNA;
  SignalLine sLine_0exMH4Xc;
  SignalTabwrite sTabwrite_eR6cTgfN;
  SignalTabwrite sTabwrite_BMYFOq4t;
  SignalRPole sRPole_jCiGmcIE;
  SignalRPole sRPole_EArzdfS3;
  SignalRPole sRPole_U7YSa7ZB;
  SignalDel1 sDel1_hoYmQqoj;
  SignalLine sLine_JmQI3gnm;
  SignalLine sLine_vC3SG7HZ;
  SignalRPole sRPole_1dunZAVl;
  SignalRPole sRPole_lCyxwSqW;
  SignalRPole sRPole_GBgfK7Lw;
  SignalDel1 sDel1_G8NiDopC;
  SignalLine sLine_gagOS7W9;
  SignalLine sLine_PRi5SYi2;
  SignalLine sLine_jTSezsyS;
  SignalLine sLine_akjWxHKk;
  ControlVar cVar_lOWHpRbI;
  ControlVar cVar_DNXyPhr2;
  ControlVar cVar_Y8jjW8rX;
  ControlVar cVar_fpm8B1Rn;
  ControlSlice cSlice_5tj1xf4R;
  ControlVar cVar_LHUDV3Ii;
  ControlSlice cSlice_OVgL4EaV;
  ControlVar cVar_vK08lEUW;
  ControlSlice cSlice_7gCkPhxF;
  ControlVar cVar_6mERq7CP;
  ControlBinop cBinop_2fe4Ju5j;
  ControlBinop cBinop_KE0CP1wy;
  ControlBinop cBinop_ypoLdb0J;
  ControlBinop cBinop_vDQbyY7N;
  ControlBinop cBinop_Iakhr6Xh;
  ControlBinop cBinop_P69sxV8R;
  ControlBinop cBinop_kBEQJTLj;
  ControlBinop cBinop_H8XaehKY;
  ControlBinop cBinop_u8jJKt05;
  ControlBinop cBinop_gpt2oeWo;
  ControlBinop cBinop_kbc4mmHQ;
  ControlBinop cBinop_tyTtkgBY;
  ControlBinop cBinop_XPddFg6S;
  ControlBinop cBinop_YS35M8vj;
  ControlBinop cBinop_If2rQCsQ;
  ControlBinop cBinop_C9xTavWn;
  ControlSlice cSlice_JvGyOUfz;
  ControlVar cVar_rwfj8GOR;
  ControlDelay cDelay_niFvq51I;
  ControlDelay cDelay_45yxREuy;
  ControlBinop cBinop_gCHmY0LW;
  HvTable hTable_Ls1VVpyH;
  ControlBinop cBinop_gBhf0rsm;
  ControlDelay cDelay_ZrJQWxxf;
  ControlDelay cDelay_2CqFZJDa;
  ControlBinop cBinop_2BxJ9Me6;
  HvTable hTable_WhfH8YcT;
  ControlBinop cBinop_Mg4DPr1h;
  ControlVar cVar_9QK88sUr;
  ControlBinop cBinop_2HB7nBzu;
  ControlBinop cBinop_TUtq9Ktq;
  SignalVarf sVarf_VfRD2TCJ;
  ControlBinop cBinop_xdY5NTUC;
  ControlBinop cBinop_hmIiZ89b;
  ControlBinop cBinop_2P0hO8n0;
  SignalVarf sVarf_IQ2x3sua;
  ControlVar cVar_ohn7zukt;
  ControlBinop cBinop_dc9yg5Eb;
  ControlBinop cBinop_X2SfxcFo;
  SignalVarf sVarf_wMi9ilX0;
  ControlBinop cBinop_sBF0UDll;
  ControlBinop cBinop_gXihUUK2;
  ControlBinop cBinop_2DdSZVpW;
  SignalVarf sVarf_Nq1URlXD;
  ControlBinop cBinop_ezXxDlIs;
  ControlBinop cBinop_pTOPFgGP;
  SignalVarf sVarf_7C694S1O;
  ControlVar cVar_Htj13Qzx;
  ControlBinop cBinop_ATrSjBFs;
  ControlBinop cBinop_naVoCblQ;
  ControlBinop cBinop_yfuTCJUr;
  ControlBinop cBinop_pnEyKxrf;
  ControlBinop cBinop_GAP5ejKt;
  ControlBinop cBinop_gQ4AEJkq;
  ControlBinop cBinop_dephv4fo;
  SignalVarf sVarf_DV9F9Vvh;
  ControlVar cVar_8KGzaxbF;
  ControlBinop cBinop_gL0IyDF9;
  ControlBinop cBinop_us2ZoiDn;
  SignalVarf sVarf_kCFHpSPW;
  SignalVarf sVarf_4UY0BBZl;
  SignalVarf sVarf_rSW9oRII;
  ControlVar cVar_WSLXkSPm;
  ControlBinop cBinop_qxPsXLDk;
  ControlBinop cBinop_XwDq5v8m;
  SignalVarf sVarf_ehGlWwp4;
  SignalVarf sVarf_o92NmmLf;
  SignalVarf sVarf_LZrIXqO6;
  ControlVar cVar_TkbOQ6Qy;
  ControlBinop cBinop_6e4Hkkam;
  ControlBinop cBinop_4y7WCigx;
  SignalVarf sVarf_VBYkEYjh;
  ControlBinop cBinop_v2blRgYQ;
  ControlBinop cBinop_4vhkweN6;
  ControlBinop cBinop_e28ilpJY;
  SignalVarf sVarf_TcpDwtq5;
  ControlVar cVar_vcEws2m0;
  ControlBinop cBinop_2Z5BYC61;
  ControlBinop cBinop_NCk2Cwl1;
  SignalVarf sVarf_42QbeMz5;
  ControlBinop cBinop_U40pQ03y;
  ControlBinop cBinop_SfM7CaC8;
  ControlBinop cBinop_qYaqYkmT;
  SignalVarf sVarf_ZSx23Ers;
  ControlBinop cBinop_u2MgFwlu;
  ControlBinop cBinop_2XkIfNPo;
  SignalVarf sVarf_LInhsxCX;
  ControlVar cVar_GxhKlf0T;
  ControlBinop cBinop_xyX7Gl8O;
  ControlBinop cBinop_WYPMhJCd;
  ControlBinop cBinop_gP3rWSXq;
  ControlBinop cBinop_943yjbFG;
  ControlBinop cBinop_hCiIRBn7;
  ControlBinop cBinop_oJtRrWm8;
  ControlBinop cBinop_o4KYskGo;
  SignalVarf sVarf_JaRKL2Mr;
  SignalVarf sVarf_Eloim9KZ;
  SignalVarf sVarf_BSz0l71g;
  ControlVar cVar_4cLN6mx0;
  ControlBinop cBinop_7HdHnfXZ;
  ControlIf cIf_fxqbWVPN;
  ControlIf cIf_R6SNyyrF;
  ControlVar cVar_owyakTwO;
  ControlVar cVar_6luy8jm6;
  ControlVar cVar_ouOkQ7uM;
  ControlVar cVar_2vLppncU;
  ControlSlice cSlice_vCNxd3NW;
  ControlSlice cSlice_CMZbqEtk;
  ControlVar cVar_vL45sRqB;
  ControlIf cIf_ROUswLlS;
  ControlBinop cBinop_0vLmhoCh;
  ControlVar cVar_h6jlEaRP;
  ControlBinop cBinop_65EglLnc;
  ControlBinop cBinop_o5ebeqU1;
  ControlBinop cBinop_eMTaHKFi;
  ControlBinop cBinop_NUnyh31E;
  ControlBinop cBinop_1evg25er;
  ControlBinop cBinop_GO42f8qn;
  ControlBinop cBinop_6CB0Q7gD;
  ControlBinop cBinop_YYo1mTka;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
